@@ -10,16 +10,7 @@ from django.conf import settings
 
 from user.forms import ProfileForm
 
-class FormMixin():
-    def construct_widgets(self, fields, placeholders):
-        for field in fields.keys():
-            if field in placeholders.keys():
-                fields[field].widget.attrs = {
-                    'class': 'form-control',
-                    'placeholder': placeholders[field]
-                }
-            else:
-                del fields[field]
+from coffee.mixins import FormMixin
     
 class SignInView(FormView, FormMixin):
     form_class = AuthenticationForm
